# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.
from trytond.model import ModelView, ModelSQL, fields
from trytond.pyson import Eval
from trytond import backend
from trytond.pool import PoolMeta

__all__ = ['Country', 'Subdivision', 'Zip']


class Country:
    'Country'
    __metaclass__ = PoolMeta
    __name__ = 'country.country'


class Subdivision:
    "Subdivision"
    __metaclass__ = PoolMeta
    __name__ = 'country.subdivision'
    ubigeo = fields.Char('Ubigeo', required=True)
    province = fields.One2Many('country.province',
            'subdivision', 'Province')

class Province(ModelSQL, ModelView):
    "Province"
    __name__ = 'country.province'
    subdivision = fields.Many2One('country.subdivision', 'Subdivision',
            required=True, select=True)
    name = fields.Char('Name', required=True, select=True, translate=True)
    ubigeo = fields.Char('Ubigeo', required=True)
    code = fields.Char('Code', required=True, select=True)
    type = fields.Selection([('province', 'Province')], 'Type', required=True )
    parent = fields.Many2One('country.province', 'Parent',
        domain=[
            ('subdivision', '=', Eval('subdivision', -1)),
            ],
        depends=['subdivision'])
    districts = fields.One2Many('country.district',
            'province', 'District')

class District(ModelSQL, ModelView):
    "District"
    __name__ = 'country.district'
    province = fields.Many2One('country.province', 'Province',
            required=True, select=True)
    name = fields.Char('Name', required=True, select=True, translate=True)
    ubigeo = fields.Char('Ubigeo', required=True)
    code = fields.Char('Code', required=True, select=True)
    type = fields.Selection([('district', 'District')], 'Type', required=True)
    parent = fields.Many2One('country.district', 'Parent',
        domain=[
            ('province', '=', Eval('province', -1)),
            ],
        depends=['province'])

class Zip:
    "Zip"
    __metaclass__ = PoolMeta
    __name__ = 'country.zip'
